"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var filter = require("lodash/filter");
var React = require("react");
var recompose_1 = require("recompose");
var ResinDeviceStatus = require("resin-device-status");
var styled_components_1 = require("styled-components");
var Gauge_1 = require("./Gauge");
var asRendition_1 = require("../asRendition");
var theme_1 = require("../theme");
var colors = theme_1.default.colors;
var pathFillColor = function (status) {
    if (status === 'idle') {
        return colors.statusIdle.main;
    }
    if (status === 'configuring') {
        return colors.statusConfiguring.main;
    }
    if (status === 'updating') {
        return colors.statusUpdating.main;
    }
    if (status === 'post-provisioning') {
        return colors.statusPostProvisioning.main;
    }
    if (status === 'offline') {
        return colors.statusOffline.main;
    }
};
var DeviceStatusGauge = function (_a) {
    var devices = _a.devices;
    var data = [];
    var allDevices = devices || [];
    ResinDeviceStatus.statuses.forEach(function (status) {
        var devices = filter(allDevices, function (d) { return ResinDeviceStatus.getStatus(d).key === status.key; });
        data.push({
            key: status.key,
            name: status.name,
            value: devices.length,
            color: pathFillColor(status.key),
        });
    });
    return (React.createElement(Gauge_1.default, { data: data, title: "Total Devices", placeholderColor: colors.statusOffline.main }));
};
exports.default = recompose_1.compose(styled_components_1.withTheme, asRendition_1.default)(DeviceStatusGauge);
